Module: Google::Cloud::BackupDR
- Defined in:
- lib/google/cloud/backupdr.rb,
lib/google/cloud/backupdr/version.rb
Constant Summary collapse
- VERSION =
"2.3.0"
Class Method Summary collapse
-
.backup_dr_protection_summary(version: :v1, transport: :grpc, &block) ⇒ ::Object
Create a new client object for BackupDrProtectionSummary.
-
.backup_dr_protection_summary_available?(version: :v1, transport: :grpc) ⇒ boolean
Determines whether the BackupDrProtectionSummary service is supported by the current client.
-
.backupdr(version: :v1, transport: :grpc, &block) ⇒ ::Object
Create a new client object for BackupDR.
-
.backupdr_available?(version: :v1, transport: :grpc) ⇒ boolean
Determines whether the BackupDR service is supported by the current client.
-
.configure {|::Google::Cloud.configure.backupdr| ... } ⇒ ::Google::Cloud::Config
Configure the google-cloud-backupdr library.
Class Method Details
.backup_dr_protection_summary(version: :v1, transport: :grpc, &block) ⇒ ::Object
Create a new client object for BackupDrProtectionSummary.
By default, this returns an instance of
Google::Cloud::BackupDR::V1::BackupDrProtectionSummary::Client
for a gRPC client for version V1 of the API.
However, you can specify a different API version by passing it in the
version parameter. If the BackupDrProtectionSummary service is
supported by that API version, and the corresponding gem is available, the
appropriate versioned client will be returned.
You can also specify a different transport by passing :rest or :grpc in
the transport parameter.
Raises an exception if the currently installed versioned client gem for the given API version does not support the given transport of the BackupDrProtectionSummary service. You can determine whether the method will succeed by calling backup_dr_protection_summary_available?.
About BackupDrProtectionSummary
The Protection Summary service.
145 146 147 148 149 150 151 152 153 154 155 |
# File 'lib/google/cloud/backupdr.rb', line 145 def self.backup_dr_protection_summary version: :v1, transport: :grpc, &block require "google/cloud/backupdr/#{version.to_s.downcase}" package_name = Google::Cloud::BackupDR .constants .select { |sym| sym.to_s.downcase == version.to_s.downcase.tr("_", "") } .first service_module = Google::Cloud::BackupDR.const_get(package_name).const_get(:BackupDrProtectionSummary) service_module = service_module.const_get(:Rest) if transport == :rest service_module.const_get(:Client).new(&block) end |
.backup_dr_protection_summary_available?(version: :v1, transport: :grpc) ⇒ boolean
Determines whether the BackupDrProtectionSummary service is supported by the current client. If true, you can retrieve a client object by calling backup_dr_protection_summary. If false, that method will raise an exception. This could happen if the given API version does not exist or does not support the BackupDrProtectionSummary service, or if the versioned client gem needs an update to support the BackupDrProtectionSummary service.
169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 |
# File 'lib/google/cloud/backupdr.rb', line 169 def self.backup_dr_protection_summary_available? version: :v1, transport: :grpc require "google/cloud/backupdr/#{version.to_s.downcase}" package_name = Google::Cloud::BackupDR .constants .select { |sym| sym.to_s.downcase == version.to_s.downcase.tr("_", "") } .first return false unless package_name service_module = Google::Cloud::BackupDR.const_get package_name return false unless service_module.const_defined? :BackupDrProtectionSummary service_module = service_module.const_get :BackupDrProtectionSummary if transport == :rest return false unless service_module.const_defined? :Rest service_module = service_module.const_get :Rest end service_module.const_defined? :Client rescue ::LoadError false end |
.backupdr(version: :v1, transport: :grpc, &block) ⇒ ::Object
Create a new client object for BackupDR.
By default, this returns an instance of
Google::Cloud::BackupDR::V1::BackupDR::Client
for a gRPC client for version V1 of the API.
However, you can specify a different API version by passing it in the
version parameter. If the BackupDR service is
supported by that API version, and the corresponding gem is available, the
appropriate versioned client will be returned.
You can also specify a different transport by passing :rest or :grpc in
the transport parameter.
Raises an exception if the currently installed versioned client gem for the given API version does not support the given transport of the BackupDR service. You can determine whether the method will succeed by calling backupdr_available?.
About BackupDR
The BackupDR Service
75 76 77 78 79 80 81 82 83 84 85 |
# File 'lib/google/cloud/backupdr.rb', line 75 def self.backupdr version: :v1, transport: :grpc, &block require "google/cloud/backupdr/#{version.to_s.downcase}" package_name = Google::Cloud::BackupDR .constants .select { |sym| sym.to_s.downcase == version.to_s.downcase.tr("_", "") } .first service_module = Google::Cloud::BackupDR.const_get(package_name).const_get(:BackupDR) service_module = service_module.const_get(:Rest) if transport == :rest service_module.const_get(:Client).new(&block) end |
.backupdr_available?(version: :v1, transport: :grpc) ⇒ boolean
Determines whether the BackupDR service is supported by the current client. If true, you can retrieve a client object by calling backupdr. If false, that method will raise an exception. This could happen if the given API version does not exist or does not support the BackupDR service, or if the versioned client gem needs an update to support the BackupDR service.
99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 |
# File 'lib/google/cloud/backupdr.rb', line 99 def self.backupdr_available? version: :v1, transport: :grpc require "google/cloud/backupdr/#{version.to_s.downcase}" package_name = Google::Cloud::BackupDR .constants .select { |sym| sym.to_s.downcase == version.to_s.downcase.tr("_", "") } .first return false unless package_name service_module = Google::Cloud::BackupDR.const_get package_name return false unless service_module.const_defined? :BackupDR service_module = service_module.const_get :BackupDR if transport == :rest return false unless service_module.const_defined? :Rest service_module = service_module.const_get :Rest end service_module.const_defined? :Client rescue ::LoadError false end |
.configure {|::Google::Cloud.configure.backupdr| ... } ⇒ ::Google::Cloud::Config
Configure the google-cloud-backupdr library.
The following configuration parameters are supported:
credentials(type:String, Hash, Google::Auth::Credentials) - The path to the keyfile as a String, the contents of the keyfile as a Hash, or a Google::Auth::Credentials object.lib_name(type:String) - The library name as recorded in instrumentation and logging.lib_version(type:String) - The library version as recorded in instrumentation and logging.interceptors(type:Array<GRPC::ClientInterceptor>) - An array of interceptors that are run before calls are executed.timeout(type:Numeric) - Default timeout in seconds.metadata(type:Hash{Symbol=>String}) - Additional headers to be sent with the call.retry_policy(type:Hash) - The retry policy. The value is a hash with the following keys::initial_delay(type:Numeric) - The initial delay in seconds.:max_delay(type:Numeric) - The max delay in seconds.:multiplier(type:Numeric) - The incremental backoff multiplier.:jitter(type:Numeric) - The jitter in seconds. Default: 1.0.:retry_codes(type:Array<String>) - The error codes that should trigger a retry.
217 218 219 220 221 |
# File 'lib/google/cloud/backupdr.rb', line 217 def self.configure yield ::Google::Cloud.configure.backupdr if block_given? ::Google::Cloud.configure.backupdr end |